# MS-AuthToken

MS-AuthToken is a PyPI library to generate Microsoft Authentication tokens for MS Graph Api and Sharepoint rest api.
MS-AuthToken library helps you generate tokens within no time. Just install the package and pass your configuration settings to generate a token.
This library supports the following token generation:

  - Microsoft Graph API
  - SharePoint Rest API

MS-AuthToken library allows you to pass your own configuration settings object as well as separate variables are also supported.

### Installation

MS-AuthToken requires pip to install.

Install the dependencies and devDependencies and start the server.


$ cd your_project_folder
$ pip install MS-AuthToken==1.2



### Todos

 - Support for more tokens
 - SSO implementation

License
----

MIT
